.g-thumbnail-container
  display inline-block
  margin 0 10px 10px 0
  vertical-align top
  position relative

  .g-thumbnail-actions-container
    border-radius 3px
    background-color rgba(255, 255, 255, 0.8)
    padding 2px 4px
    position absolute
    top 4px
    right 4px
    font-size 12px
    display inline-block
    opacity 0
    transition opacity 400ms

    &.g-show
      opacity 1

    a
      color #333

.g-thumbnails-header-container
  margin-bottom 8px
